@@ -9,7 +9,7 @@ from scrapinghub.client.exceptions import NotFound
 from scrapinghub.client.jobs import Job
 from scrapy import Item
 
-from shub_workflow.script import BaseScript, JobKey
+from shub_workflow.script import BaseScript, BaseLoopScript, JobKey
 from shub_workflow.deliver.dupefilter import SqliteDictDupesFilter, DupesFilterProtocol
 
 _LOG = logging.getLogger(__name__)
@@ -22,7 +22,9 @@ class DeliverScriptProtocol(Protocol):
     SCRAPERNAME_NARGS: Union[str, int]
 
     @abc.abstractmethod
-    def get_delivery_spider_jobs(self, scrapername: str, target_tags: List[str]) -> Generator[Job, None, None]:
+    def get_delivery_spider_jobs(
+        self, scrapername: str, target_tags: List[str], include_running: bool = False
+    ) -> Generator[Job, None, None]:
         ...
 
     @abc.abstractmethod
@@ -30,7 +32,7 @@ class DeliverScriptProtocol(Protocol):
         ...
 
 
-class BaseDeliverScript(BaseScript, DeliverScriptProtocol):
+class BaseDeliverScript(BaseLoopScript, DeliverScriptProtocol):
 
     DELIVERED_TAG = "delivered"
     SCRAPERNAME_NARGS: Union[str, int] = "+"
@@ -70,20 +72,28 @@ class BaseDeliverScript(BaseScript, DeliverScriptProtocol):
         """
         return []
 
-    def get_delivery_spider_jobs(self, scrapername: str, target_tags: List[str]) -> Generator[Job, None, None]:
+    def get_delivery_spider_jobs(
+        self, scrapername: str, target_tags: List[str], include_running: bool = False
+    ) -> Generator[Job, None, None]:
         if self.flow_id:
             flow_id_tag = [f"FLOW_ID={self.flow_id}"]
             target_tags = flow_id_tag + target_tags
-        yield from self.get_jobs_with_tags(scrapername, target_tags, state=["finished"], lacks_tag=[self.DELIVERED_TAG])
+        state = ["finished", "running", "pending"] if include_running else ["finished"]
+        yield from self.get_jobs_with_tags(scrapername, target_tags, state=state, lacks_tag=[self.DELIVERED_TAG])
 
-    def process_spider_jobs(self, scrapername: str):
+    def process_spider_jobs(self, scrapername: str) -> bool:
         target_tags = self.get_target_tags()
-        for sj in self.get_delivery_spider_jobs(scrapername, target_tags):
-            self.process_job_items(scrapername, sj)
-            if not self.args.test_mode:
-                self._all_jobs_to_tag.append(sj.key)
-            if self.total_items_count >= self.MAX_PROCESSED_ITEMS:
-                break
+        there_are_running = False
+        for sj in self.get_delivery_spider_jobs(scrapername, target_tags, include_running=True):
+            if sj.metadata.get("state") == "finished":
+                self.process_job_items(scrapername, sj)
+                if not self.args.test_mode:
+                    self._all_jobs_to_tag.append(sj.key)
+                if self.total_items_count >= self.MAX_PROCESSED_ITEMS:
+                    break
+            else:
+                there_are_running = True
+        return there_are_running
 
     def get_item_unique_key(self, item: Item) -> str:
         assert all(isinstance(item[f], str) for f in self.DEDUPE_KEY_BY_FIELDS)
@@ -113,11 +123,12 @@ class BaseDeliverScript(BaseScript, DeliverScriptProtocol):
     def on_item(self, item: Item, scrapername: str):
         print(json.dumps(item))
 
-    def run(self):
+    def workflow_loop(self) -> bool:
+        retval = False
         for scrapername in self.args.scrapername:
             _LOG.info(f"Processing spider {scrapername}")
-            self.process_spider_jobs(scrapername)
-        self.on_close()
+            retval = retval or self.process_spider_jobs(scrapername)
+        return retval
 
     def on_close(self):
         _LOG.info(f"Processed a total of {self.total_items_count} items.")
@@ -193,11 +204,13 @@ class CachedDeliveredTagsMixin(DeliverScriptProtocol):
                 col.set(record)
             _LOG.info(f"Synced delivered cache ({to_store_count} jobs).")
 
-    def get_delivery_spider_jobs(self, scrapername: str, target_tags: List[str]) -> Generator[Job, None, None]:
+    def get_delivery_spider_jobs(
+        self, scrapername: str, target_tags: List[str], include_running: bool = False
+    ) -> Generator[Job, None, None]:
         if self._cache is None:
             self.get_delivered_cached()
         assert self._cache is not None
-        for sj in super().get_delivery_spider_jobs(scrapername, target_tags):
+        for sj in super().get_delivery_spider_jobs(scrapername, target_tags, include_running):
             if sj.key not in self._cache:
                 yield sj
 
